package org.apache.commons.lang3.function;

import java.lang.Throwable;
import java.util.Objects;

/* loaded from: org_apache_commons_lang3_function.jar:org/apache/commons/lang3/function/FailableLongUnaryOperator.class */
public interface FailableLongUnaryOperator<E extends Throwable> {
    public static final FailableLongUnaryOperator NOP = t -> {
        return 0L;
    };

    long applyAsLong(long j) throws Throwable;

    static <E extends Throwable> FailableLongUnaryOperator<E> identity() {
        return t -> {
            return t;
        };
    }

    static <E extends Throwable> FailableLongUnaryOperator<E> nop() {
        return NOP;
    }

    default FailableLongUnaryOperator<E> andThen(FailableLongUnaryOperator<E> after) {
        Objects.requireNonNull(after);
        return t -> {
            return after.applyAsLong(applyAsLong(t));
        };
    }

    default FailableLongUnaryOperator<E> compose(FailableLongUnaryOperator<E> before) {
        Objects.requireNonNull(before);
        return v -> {
            return applyAsLong(before.applyAsLong(v));
        };
    }
}
